@@ -41,7 +41,7 @@ class MesosTaskConfig(PRecord):
         return ('image' in conf if conf.containerizer == 'DOCKER' else True,
                 'Image required for chosen containerizer')
 
-    uuid = field(type=uuid.UUID, initial=uuid.uuid4)
+    uuid = field(type=(str, uuid.UUID), initial=uuid.uuid4)
     name = field(type=str, initial="default")
     # image is optional for the mesos containerizer
     image = field(type=str)
@@ -68,6 +68,12 @@ class MesosTaskConfig(PRecord):
                     factory=float,
                     mandatory=False,
                     invariant=lambda t: (t > 0, 'timeout > 0'))
+    # By default, the retrying executor retries 3 times. This task option
+    # overrides the executor setting.
+    retries = field(type=int,
+                    factory=int,
+                    mandatory=False,
+                    invariant=lambda r: (r >= 0, 'retries >= 0'))
     volumes = field(type=PVector,
                     initial=v(),
                     factory=pvector,
@@ -87,7 +93,7 @@ class MesosTaskConfig(PRecord):
 
     @property
     def task_id(self):
-        return "{}.{}".format(self.name, str(self.uuid))
+        return "{}.{}".format(self.name, self.uuid)
 
 
 class MesosExecutor(TaskExecutor):
